@@ -62,6 +62,7 @@ public:
 	Glib::ustring get_thread_status_message() ;
 
 	FileSystem * get_filesystem_object( const FILESYSTEM & filesystem ) ;
+	static bool filesystem_resize_disallowed( const Partition & partition ) ;
 private:
 	//detectionstuff..
 	void init_maps() ;
@@ -84,6 +85,7 @@ private:
 				 bool inside_extended ) ;
 	void set_mountpoints( std::vector<Partition> & partitions ) ;
 	void set_used_sectors( std::vector<Partition> & partitions ) ;
+	void mounted_set_used_sectors( Partition & partition ) ;
 #ifdef HAVE_LIBPARTED_FS_RESIZE
 	void LP_set_used_sectors( Partition & partition );
 #endif
@@ -97,7 +99,9 @@ private:
 	bool format( const Partition & partition, OperationDetail & operationdetail ) ;
 
 	bool Delete( const Partition & partition, OperationDetail & operationdetail ) ;
-	
+
+	bool remove_filesystem( const Partition & partition, OperationDetail & operationdetail ) ;
+
 	bool label_partition( const Partition & partition, OperationDetail & operation_detail ) ;
 	
 	bool change_uuid( const Partition & partition, OperationDetail & operation_detail ) ;
