@@ -51,9 +51,6 @@ enum PartitionAlignment {
 	                       //  Indicator if start and end sectors must remain unchanged
 };
 
-//FIXME: we should make a difference between partition- and file system size. 
-//especially in the core this can make a difference when giving detailed feedback. With new cairosupport in gtkmm
-//it's even possible to make stuff like this visible in the GUI in a nice and clear way
 class Partition
 {
 public:
@@ -75,8 +72,13 @@ public:
 			bool inside_extended,
 			bool busy ) ;
 
-	void Set_Unused( Sector sectors_unused ) ;
-	void set_used( Sector sectors_used ) ;
+	void set_sector_usage( Sector sectors_fs_size, Sector sectors_fs_unused ) ;
+	bool sector_usage_known() const ;
+	Sector estimated_min_size() const ;
+	Sector get_sectors_used() const ;
+	Sector get_sectors_unused() const ;
+	Sector get_sectors_unallocated() const ;
+	void get_usage_triple( int imax, int & i1, int & i2, int & i3 ) const ;
 
 	void Set_Unallocated( const Glib::ustring & device_path, 
 			      Sector sector_start,
@@ -117,6 +119,8 @@ public:
 	Sector sector_end;
 	Sector sectors_used;
 	Sector sectors_unused;
+	Sector sectors_unallocated;  //Difference between the size of the partition and the file system
+	Sector significant_threshold;  //Threshold from intrinsic to significant unallocated sectors
 	Gdk::Color color;
 	bool inside_extended;
 	bool busy;
@@ -131,7 +135,10 @@ public:
 	Byte_Value sector_size ;  //Sector size of the disk device needed for converting to/from sectors and bytes.
 
 private:
+	static void get_usage_triple_helper( Sector stot, Sector s1, Sector s2, Sector s3, int imax, int & i1, int & i2, int & i3 ) ;
+
 	void sort_paths_and_remove_duplicates() ;
+	Sector calc_significant_unallocated_sectors() const ;
 
 	static bool compare_paths( const Glib::ustring & A, const Glib::ustring & B ) ;
 	
