@@ -35,6 +35,9 @@
 #include <vector>
 
 #define UUID_STRING_LENGTH 36
+//Match RFC 4122 UUID strings.  Exclude Nil UUID (all zeros) by excluding
+//  zero from the version field nibble.
+#define RFC4122_NONE_NIL_UUID_REGEXP "[[:xdigit:]]{8}-[[:xdigit:]]{4}-[1-9a-fA-F][[:xdigit:]]{3}-[[:xdigit:]]{4}-[[:xdigit:]]{12}"
 
 namespace GParted
 {
@@ -97,9 +100,10 @@ enum SIZE_UNIT
 enum CUSTOM_TEXT
 {
 	CTEXT_NONE,
-	CTEXT_ACTIVATE_FILESYSTEM,		// Activate text ('Mount', 'Swapon', ...)
-	CTEXT_DEACTIVATE_FILESYSTEM,		// Deactivate text ('Unmount', 'Swapoff', ...)
+	CTEXT_ACTIVATE_FILESYSTEM,		// Activate text ('Mount', 'Swapon', VG 'Activate', ...)
+	CTEXT_DEACTIVATE_FILESYSTEM,		// Deactivate text ('Unmount', 'Swapoff', VG 'Deactivate', ...)
 	CTEXT_CHANGE_UUID_WARNING,		// Warning to print when changing UUIDs
+	CTEXT_RESIZE_DISALLOWED_WARNING		// File system resizing currently disallowed reason
 } ;
 
 //struct to store file system information
@@ -114,7 +118,7 @@ struct FS
 	};
 
 	FILESYSTEM filesystem ;
-	Support read ; //can we get the amount of used sectors?
+	Support read ;  //Can and how to read sector usage while inactive
 	Support read_label ;
 	Support write_label ;
 	Support read_uuid ;
@@ -125,13 +129,16 @@ struct FS
 	Support move ; //startpoint and endpoint
 	Support check ; //some checktool available?
 	Support copy ;
+	Support remove ;
+	Support online_read ;  //Can and how to read sector usage while active
 
 	Byte_Value MIN ; 
 	Byte_Value MAX ;
 	
 	FS()
 	{
-		read = read_label = write_label = read_uuid = write_uuid = create = grow = shrink = move = check = copy = NONE;
+		read = read_label = write_label = read_uuid = write_uuid = create = grow = shrink =
+		move = check = copy = remove = online_read = NONE ;
 		MIN = MAX = 0 ;
 	} 
 } ;
@@ -181,6 +188,9 @@ public:
 	                   const Glib::ustring& delimiters     ) ;
 	static int convert_to_int(const Glib::ustring & src);
 	static Glib::ustring generate_uuid(void);
+	static int get_mounted_filesystem_usage( const Glib::ustring & mountpoint,
+	                                         Byte_Value & fs_size, Byte_Value & fs_free,
+	                                         Glib::ustring error_message ) ;
 
 private:
 	static bool get_kernel_version( int & major_ver, int & minor_ver, int & patch_ver ) ;
