@@ -92,9 +92,9 @@ private:
 		
 	void allow_format( bool state )	{ 
 		toggle_item( state, MENU_FORMAT ) ; }
-	
-	void allow_toggle_swap_mount_state( bool state )	{ 
-		toggle_item( state, MENU_TOGGLE_MOUNT_SWAP ) ; }
+
+	void allow_toggle_busy_state( bool state )	{
+		toggle_item( state, MENU_TOGGLE_BUSY ) ; }
 
 	void allow_manage_flags( bool state ) {
 		toggle_item( state, MENU_FLAGS ) ; } 
@@ -130,6 +130,7 @@ private:
 	void thread_unmount_partition( bool * succes, Glib::ustring * error ) ;
 	void thread_mount_partition( Glib::ustring mountpoint, bool * succes, Glib::ustring * error ) ;
 	void thread_toggle_swap( bool * succes, Glib::ustring * error ) ;
+	void thread_toggle_lvm2_pv( bool * succes, Glib::ustring * error ) ;
 	void thread_guess_partition_table();
 		
 	//signal handlers
@@ -164,7 +165,7 @@ private:
 	void activate_delete();
 	void activate_info();
 	void activate_format( GParted::FILESYSTEM new_fs );
-	void toggle_swap_mount_state() ;
+	void toggle_busy_state() ;
 	void activate_mount_partition( unsigned int index ) ;
 	void activate_disklabel() ;
 	void activate_attempt_rescue_data();
@@ -178,6 +179,7 @@ private:
 	int  partition_in_operation_queue_count( const Partition & partition ) ;
 	int  active_partitions_on_device_count( const Device & device ) ;
 	void activate_apply();
+	bool remove_non_empty_lvm2_pv_dialog( const OperationType optype ) ;
 
 //private variables
 	unsigned int current_device ;
@@ -235,7 +237,7 @@ private:
         MENU_COPY, TOOLBAR_COPY,
         MENU_PASTE, TOOLBAR_PASTE,
         MENU_FORMAT,
-        MENU_TOGGLE_MOUNT_SWAP,
+        MENU_TOGGLE_BUSY,
         MENU_MOUNT,
         MENU_FLAGS,
         MENU_CHECK,
