@@ -19,6 +19,8 @@
 #include "../include/Dialog_Partition_Info.h"
 #include "../include/LVM2_PV_Info.h"
 
+#include <gtkmm/separator.h>
+
 namespace GParted
 {
 
@@ -97,6 +99,10 @@ bool Dialog_Partition_Info::drawingarea_on_expose( GdkEventExpose *ev )
 		//unused
 		gc ->set_foreground( color_unused );
 		drawingarea .get_window() ->draw_rectangle( gc, true, BORDER + used, BORDER, unused, 44 ) ;
+
+		//unallocated
+		gc ->set_foreground( color_unallocated );
+		drawingarea .get_window() ->draw_rectangle( gc, true, BORDER + used + unused, BORDER, unallocated, 44 ) ;
 	}
 	
 	//text
@@ -122,20 +128,36 @@ void Dialog_Partition_Info::init_drawingarea()
 	
 	this ->get_vbox() ->pack_start( *hbox, Gtk::PACK_SHRINK ) ;
 	
-	//calculate proportional width of used and unused
-	used = unused = 0 ;
-	used = Utils::round( 
-		(400 - BORDER *2) / ( static_cast<double>( partition .get_sector_length() ) / partition .sectors_used ) ) ;
-	
-	unused = 400 - used - BORDER *2 ;
+	//calculate proportional width of used, unused and unallocated
+	if ( partition .type == GParted::TYPE_EXTENDED )
+	{
+		//Specifically show extended partitions as unallocated
+		used        = 0 ;
+		unused      = 0 ;
+		unallocated = 400 - BORDER *2 ;
+	}
+	else if ( partition .sector_usage_known() )
+	{
+		partition .get_usage_triple( 400 - BORDER *2, used, unused, unallocated ) ;
+	}
+	else
+	{
+		//Specifically show unknown figures as unused
+		used        = 0 ;
+		unused      = 400 - BORDER *2 ;
+		unallocated = 0 ;
+	}
 	
 	//allocate some colors
 	color_used.set( "#F8F8BA" );
 	this ->get_colormap() ->alloc_color( color_used ) ;
 	
-	color_unused .set( partition .type == GParted::TYPE_EXTENDED ? "darkgrey" : "white" ) ;
+	color_unused .set( "white" ) ;
 	this ->get_colormap() ->alloc_color( color_unused ) ;
 
+	color_unallocated .set( "darkgrey" ) ;
+	this ->get_colormap() ->alloc_color( color_unallocated ) ;
+
 	color_text .set( "black" );
 	this ->get_colormap() ->alloc_color( color_text ) ;
 	
@@ -150,7 +172,9 @@ void Dialog_Partition_Info::init_drawingarea()
 void Dialog_Partition_Info::Display_Info()
 {  
 	int top = 0, bottom = 1 ;
-	
+	Sector ptn_sectors = partition .get_sector_length() ;
+	LVM2_PV_Info lvm2_pv_info ;
+
 	Gtk::Table* table(manage(new Gtk::Table()));
 
 	table ->set_border_width( 5 ) ;
@@ -172,46 +196,68 @@ void Dialog_Partition_Info::Display_Info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL) ;
-	table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sector_length(), partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+	table ->attach( * Utils::mk_label( Utils::format_size( ptn_sectors, partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
 			1, 2,
 			top++, bottom++,
 			Gtk::FILL ) ;
 	
-	if ( partition.sectors_used != -1 )
+	if ( partition .sector_usage_known() )
 	{
 		//calculate relative diskusage
-		int percent_used = 
-			Utils::round( partition .sectors_used / static_cast<double>( partition .get_sector_length() ) * 100 ) ;
-						
-		//used
+		int percent_used, percent_unused, percent_unallocated ;
+		partition .get_usage_triple( 100, percent_used, percent_unused, percent_unallocated ) ;
+
+		//Used
 		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Used:") ) + "</b>" ),
 				0, 1,
 				top, bottom,
 				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Utils::format_size( partition .sectors_used, partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_used(), partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
 				1, 2,
 				top, bottom,
 				Gtk::FILL ) ;
 		table ->attach( * Utils::mk_label( "\t\t\t( " + Utils::num_to_str( percent_used ) + "% )"),
 				1, 2,
 				top++, bottom++,
-				Gtk::FILL ) ; 
-		
+				Gtk::FILL ) ;
+
 		//unused
 		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Unused:") ) + "</b>" ),
 				0, 1,
 				top, bottom,
 				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Utils::format_size( partition .sectors_unused, partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_unused(), partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
 				1, 2,
 				top, bottom,
 				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( "\t\t\t( " + Utils::num_to_str( 100 - percent_used ) + "% )"),
+		table ->attach( * Utils::mk_label( "\t\t\t( " + Utils::num_to_str( percent_unused ) + "% )"),
 				1, 2,
 				top++, bottom++,
-				Gtk::FILL ) ; 
+				Gtk::FILL ) ;
+
+		//unallocated
+		Sector sectors_unallocated = partition .get_sectors_unallocated() ;
+		if ( sectors_unallocated > 0 )
+		{
+			table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Unallocated:") ) + "</b>" ),
+					0, 1,
+					top, bottom,
+					Gtk::FILL ) ;
+			table ->attach( * Utils::mk_label( Utils::format_size( sectors_unallocated, partition .sector_size ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+					1, 2,
+					top, bottom,
+					Gtk::FILL ) ;
+			table ->attach( * Utils::mk_label( "\t\t\t( " + Utils::num_to_str( percent_unallocated ) + "% )"),
+					1, 2,
+					top++, bottom++,
+					Gtk::FILL ) ;
+		}
 	}
-	
+
+	Glib::ustring vgname = "" ;
+	if ( partition .filesystem == FS_LVM2_PV )
+		vgname = lvm2_pv_info .get_vg_name( partition .get_path() ) ;
+
 	//flags
 	if ( partition.type != GParted::TYPE_UNALLOCATED )
 	{
@@ -273,7 +319,7 @@ void Dialog_Partition_Info::Display_Info()
 				 * means that the partition is a member of an LVM volume group and the
 				 * volume group is active and being used by the operating system.
 				 */
-				str_temp = String::ucompose( _("%1 active"), partition .get_mountpoint() ) ;
+				str_temp = String::ucompose( _("%1 active"), vgname ) ;
 			}
 			else if ( partition .get_mountpoints() .size() )
 			{
@@ -301,29 +347,27 @@ void Dialog_Partition_Info::Display_Info()
 		}
 		else if ( partition .filesystem == FS_LVM2_PV )
 		{
-			LVM2_PV_Info lvm2_pv_info ;
-			Glib::ustring mount_point = partition .get_mountpoint() ;
-			if ( mount_point .empty() )
+			if ( vgname .empty() )
 				/* TO TRANSLATORS:  Not active (Not a member of any volume group)
 				 * means that the partition is not yet a member of an LVM volume
 				 * group and therefore is not active and can not yet be used by
 				 * the operating system.
 				 */
 				str_temp = _("Not active (Not a member of any volume group)") ;
-			else if ( lvm2_pv_info .is_vg_exported( mount_point ) )
+			else if ( lvm2_pv_info .is_vg_exported( vgname ) )
 				/* TO TRANSLATORS:  myvgname not active and exported
 				 * means that the partition is a member of an LVM volume group but
 				 * the volume group is not active and not being used by the operating system.
 				 * The volume group has also been exported making the LVM physical volumes
 				 * ready for moving to a different computer system.
 				 */
-				str_temp = String::ucompose( _("%1 not active and exported"), mount_point ) ;
+				str_temp = String::ucompose( _("%1 not active and exported"), vgname ) ;
 			else
 				/* TO TRANSLATORS:  myvgname not active
 				 * means that the partition is a member of an LVM volume group but
 				 * the volume group is not active and not being used by the operating system.
 				 */
-				str_temp = String::ucompose( _("%1 not active"), mount_point ) ;
+				str_temp = String::ucompose( _("%1 not active"), vgname ) ;
 		}
 		else
 		{
@@ -390,10 +434,51 @@ void Dialog_Partition_Info::Display_Info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( partition .get_sector_length() ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+	table ->attach( * Utils::mk_label( Utils::num_to_str( ptn_sectors ), true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
 			1, 2,
 			top++, bottom++,
 			Gtk::FILL ) ;
+
+	if ( partition .filesystem == FS_LVM2_PV )
+	{
+		//one blank line
+		table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
+
+		//horizontal separator
+		Gtk::HSeparator * hsep( manage( new Gtk::HSeparator() ) ) ;
+		table ->attach( * hsep, 0, 2, top++, bottom++, Gtk::FILL ) ;
+
+		//one blank line
+		table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
+
+		//Volume Group
+		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Volume Group:") ) + "</b>"),
+		                0, 1, top, bottom, Gtk::FILL ) ;
+		table ->attach( * Utils::mk_label( vgname, true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+		                1, 2, top++, bottom++, Gtk::FILL ) ;
+
+		//Members
+		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Members:") ) + "</b>"),
+		                0, 1, top, bottom, Gtk::FILL ) ;
+
+		std::vector<Glib::ustring> members ;
+		if ( ! vgname .empty() )
+			members = lvm2_pv_info .get_vg_members( vgname ) ;
+
+		if ( members .empty() )
+			table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
+		else
+		{
+			table ->attach( * Utils::mk_label( members [0], true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+			                1, 2, top++, bottom++, Gtk::FILL ) ;
+			for ( unsigned int i = 1 ; i < members .size() ; i ++ )
+			{
+				table ->attach( * Utils::mk_label( "" ), 0, 1, top, bottom, Gtk::FILL) ;
+				table ->attach( * Utils::mk_label( members [i], true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+				                1, 2, top++, bottom++, Gtk::FILL ) ;
+			}
+		}
+	}
 }
 
 Dialog_Partition_Info::~Dialog_Partition_Info()
