@@ -1,4 +1,5 @@
 /* Copyright (C) 2004 Bart 'plors' Hakvoort
+ * Copyright (C) 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,6 +45,7 @@ void OperationDelete::apply_to_visual( std::vector<Partition> & partitions )
 			insert_unallocated( partitions[ index_extended ] .logicals,
 					    partitions[ index_extended ] .sector_start,
 					    partitions[ index_extended ] .sector_end,
+					    device .sector_size,
 					    true ) ;
 		
 			//if deleted partition was logical we have to decrease the partitionnumbers of the logicals
@@ -64,7 +66,7 @@ void OperationDelete::apply_to_visual( std::vector<Partition> & partitions )
 		{
 			remove_original_and_adjacent_unallocated( partitions, index ) ;
 			
-			insert_unallocated( partitions, 0, device .length -1, false ) ;
+			insert_unallocated( partitions, 0, device .length -1, device .sector_size, false ) ;
 		}
 	}
 }
@@ -80,7 +82,7 @@ void OperationDelete::create_description()
 	description = String::ucompose( _("Delete %1 (%2, %3) from %4"),
 					description,
 					Utils::get_filesystem_string( partition_original .filesystem ), 
-					Utils::format_size( partition_original .get_length() ),
+					Utils::format_size( partition_original .get_sector_length(), partition_original .sector_size ),
 					partition_original .device_path ) ;
 }
 	
