@@ -35,12 +35,14 @@
 #include "../include/OperationResizeMove.h"
 #include "../include/OperationChangeUUID.h"
 #include "../include/OperationLabelPartition.h"
+#include "../include/LVM2_PV_Info.h"
 #include "../config.h"
 
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/radiobuttongroup.h>
 #include <gtkmm/main.h>
+#include <gtkmm/separator.h>
 
 namespace GParted
 {
@@ -61,7 +63,7 @@ Win_GParted::Win_GParted( const std::vector<Glib::ustring> & user_devices )
         MENU_COPY = TOOLBAR_COPY =
         MENU_PASTE = TOOLBAR_PASTE =
         MENU_FORMAT =
-        MENU_TOGGLE_MOUNT_SWAP =
+        MENU_TOGGLE_BUSY =
         MENU_MOUNT =
         MENU_FLAGS =
         MENU_INFO =
@@ -359,9 +361,9 @@ void Win_GParted::init_partition_menu()
 	menu_partition .items() .push_back(
 			//This is a placeholder text. It will be replaced with some other text before it is used
 			Gtk::Menu_Helpers::MenuElem( "--placeholder--",
-						     sigc::mem_fun( *this, &Win_GParted::toggle_swap_mount_state ) ) );
-	MENU_TOGGLE_MOUNT_SWAP = index++ ;
-		
+						     sigc::mem_fun( *this, &Win_GParted::toggle_busy_state ) ) );
+	MENU_TOGGLE_BUSY = index++ ;
+
 	/*TO TRANSLATORS: menuitem which holds a submenu with mount points.. */
 	menu_partition .items() .push_back(
 			Gtk::Menu_Helpers::MenuElem( _("_Mount on"), * manage( new Gtk::Menu() ) ) ) ;
@@ -407,10 +409,9 @@ Gtk::Menu * Win_GParted::create_format_menu()
 
 	for ( unsigned int t =0; t < gparted_core .get_filesystems() .size() ; t++ )
 	{
-		//Skip luks, lvm2, and unknown because these are not file systems
+		//Skip luks and unknown because these are not file systems
 		if (
 		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_LUKS    ||
-		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_LVM2_PV ||
 		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_UNKNOWN
 		   )
 			continue ;
@@ -721,7 +722,7 @@ void Win_GParted::Add_Operation( Operation * operation, int index )
 		else
 		{
 			Gtk::MessageDialog dialog( *this,
-				   _("Could not add this operation to the list."),
+				   _("Could not add this operation to the list"),
 				   false,
 				   Gtk::MESSAGE_ERROR,
 				   Gtk::BUTTONS_OK,
@@ -907,14 +908,14 @@ bool Win_GParted::Quit_Check_Operations()
 void Win_GParted::set_valid_operations()
 {
 	allow_new( false ); allow_delete( false ); allow_resize( false ); allow_copy( false );
-	allow_paste( false ); allow_format( false ); allow_toggle_swap_mount_state( false ) ;
+	allow_paste( false ); allow_format( false ); allow_toggle_busy_state( false ) ;
 	allow_manage_flags( false ) ; allow_check( false ) ; allow_label_partition( false ) ;
 	allow_change_uuid( false ); allow_info( false ) ;
-	
-	dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .get_child() )
+
+	dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_BUSY ] .get_child() )
 		->set_label( FileSystem::get_generic_text ( CTEXT_DEACTIVATE_FILESYSTEM ) ) ;
 
-	menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .show() ;
+	menu_partition .items()[ MENU_TOGGLE_BUSY ] .show() ;
 	menu_partition .items()[ MENU_MOUNT ] .hide() ;	
 
 	//no partition selected...	
@@ -930,7 +931,7 @@ void Win_GParted::set_valid_operations()
 
 	//Activate / deactivate
 	if ( gparted_core .get_filesystem_object ( selected_partition .filesystem ) )
-		dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .get_child() )
+		dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_BUSY ] .get_child() )
 			->set_label( gparted_core .get_filesystem_object ( selected_partition .filesystem )
 			             ->get_custom_text (  selected_partition .busy
 			                                ? CTEXT_DEACTIVATE_FILESYSTEM
@@ -938,7 +939,7 @@ void Win_GParted::set_valid_operations()
 			                               )
 			           ) ;
 	else
-		dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .get_child() )
+		dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_BUSY ] .get_child() )
 			->set_label( FileSystem::get_generic_text (  selected_partition .busy
 			                                           ? CTEXT_DEACTIVATE_FILESYSTEM
 			                                           : CTEXT_ACTIVATE_FILESYSTEM )
@@ -953,9 +954,24 @@ void Win_GParted::set_valid_operations()
 	          || selected_partition .filesystem == GParted::FS_LINUX_SWAP
 	        )
 	   )
-		allow_toggle_swap_mount_state( true ) ;
+		allow_toggle_busy_state( true ) ;
 
-	//only unmount/swapoff/... is allowed if busy
+	//Only permit VG deactivation if busy, or activation if not busy and a member of a VG.
+	//  For now specifically allow activation of an exported VG, which LVM will fail
+	//  with "Volume group "VGNAME" is exported", otherwise user won't know why the
+	//  inactive PV can't be activated.
+	if (    selected_partition .status == GParted::STAT_REAL
+	     && selected_partition .type != GParted::TYPE_EXTENDED
+	     && selected_partition .filesystem == GParted::FS_LVM2_PV
+	     && (    selected_partition .busy
+	          || (    ! selected_partition .busy
+                       && ! selected_partition .get_mountpoints() .empty()  //VGNAME from mount point
+	             )
+	        )
+	   )
+		allow_toggle_busy_state( true ) ;
+
+	//only unmount/swapoff/VG deactivate/... is allowed if busy
 	if ( selected_partition .busy )
 		return ;
 
@@ -969,7 +985,7 @@ void Win_GParted::set_valid_operations()
 		{
 			Byte_Value required_size ;
 			if ( copied_partition .filesystem == GParted::FS_XFS )
-				required_size = copied_partition .sectors_used * copied_partition .sector_size;
+				required_size = copied_partition .estimated_min_size() * copied_partition .sector_size;
 			else
 				required_size = copied_partition .get_byte_length() ;
 
@@ -1072,8 +1088,8 @@ void Win_GParted::set_valid_operations()
 
 				dynamic_cast<Gtk::Label*>( menu ->items() .back() .get_child() ) ->set_use_underline( false ) ;
 			}
-			
-			menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .hide() ;
+
+			menu_partition .items()[ MENU_TOGGLE_BUSY ] .hide() ;
 			menu_partition .items()[ MENU_MOUNT ] .show() ;	
 		}
 
@@ -1365,7 +1381,7 @@ void Win_GParted::show_help_dialog( const Glib::ustring & filename /* E.g., gpar
 	if ( error != NULL )
 	{
 		Gtk::MessageDialog dialog( *this
-		                         , _( "Unable to open GParted Manual help file." )
+		                         , _( "Unable to open GParted Manual help file" )
 		                         , false
 		                         , Gtk::MESSAGE_ERROR
 		                         , Gtk::BUTTONS_OK
@@ -1381,7 +1397,7 @@ void Win_GParted::menu_help_contents()
 #ifdef HAVE_DISABLE_DOC
 	//GParted was configured with --disable-doc
 	Gtk::MessageDialog dialog( *this,
-			_( "Documentation is not available." ),
+			_( "Documentation is not available" ),
 			false,
 			Gtk::MESSAGE_INFO,
 			Gtk::BUTTONS_OK,
@@ -1413,13 +1429,23 @@ void Win_GParted::menu_help_about()
 	dialog .set_copyright( "Copyright © 2004-2006 Bart Hakvoort\nCopyright © 2008-2012 Curtis Gedak" ) ;
 
 	//authors
-	strings .push_back( "Bart Hakvoort <gparted@users.sf.net>" ) ;
+	//Names listed in alphabetical order by LAST name.
+	//See also AUTHORS file -- names listed in opposite order to try to be fair.
+	strings .push_back( "Luca Bruno <lucab@debian.org>" ) ;
+	strings .push_back( "Jérôme Dumesnil <jerome.dumesnil@gmail.com>" ) ;
+	strings .push_back( "Markus Elfring <elfring@users.sourceforge.net>" ) ;
+	strings .push_back( "Mike Fleetwood <mike.fleetwood@googlemail.com>" ) ;
 	strings .push_back( "Curtis Gedak <gedakc@users.sf.net>" ) ;
+	strings .push_back( "Rogier Goossens <goossens.rogier@gmail.com>" ) ;
+	strings .push_back( "Bart Hakvoort <gparted@users.sf.net>" ) ;
+	strings .push_back( "Seth Heeren <sgheeren@gmail.com>" ) ;
+	strings .push_back( "Joan Lledó <joanlluislledo@gmail.com>" ) ;
+	strings .push_back( "Phillip Susi <psusi@cfl.rr.com>" ) ;
 	dialog .set_authors( strings ) ;
 	strings .clear() ;
 
 	//artists
-	strings .push_back( "http://gparted.org/artwork.php" ) ;
+	strings .push_back( "Sebastian Kraft <kraft.sebastian@gmail.com>" ) ;
 	dialog .set_artists( strings ) ;
 	strings .clear() ;
 
@@ -1562,7 +1588,7 @@ void Win_GParted::activate_resize()
 			{
 				//Warn that move operation might break boot process
 				Gtk::MessageDialog dialog( *this
-				                         , _( "Moving a partition might cause your operating system to fail to boot." )
+				                         , _( "Moving a partition might cause your operating system to fail to boot" )
 				                         , false
 				                         , Gtk::MESSAGE_WARNING
 				                         , Gtk::BUTTONS_OK
@@ -1635,13 +1661,39 @@ void Win_GParted::activate_paste()
 	}
 	else
 	{
+		bool shown_dialog = false ;
+		//VGNAME from mount mount
+		if ( selected_partition .filesystem == FS_LVM2_PV && ! selected_partition .get_mountpoint() .empty() )
+		{
+			if ( ! remove_non_empty_lvm2_pv_dialog( OPERATION_COPY ) )
+				return ;
+			shown_dialog = true ;
+		}
+
 		Partition partition_new = selected_partition ;
 		partition_new .alignment = ALIGN_STRICT ;
 		partition_new .filesystem = copied_partition .filesystem ;
 		partition_new .label = copied_partition .label ;
 		partition_new .uuid = copied_partition .uuid ;
 		partition_new .color = copied_partition .color ;
-		partition_new .set_used( copied_partition .sectors_used ) ;
+		Sector new_size = partition_new .get_sector_length() ;
+		if ( copied_partition .get_sector_length() == new_size )
+		{
+			//Pasting into same size existing partition, therefore only block copy operation
+			//  will be performed maintaining the file system size.
+			partition_new .set_sector_usage(
+					copied_partition .sectors_used + copied_partition. sectors_unused,
+					copied_partition. sectors_unused ) ;
+		}
+		else
+		{
+			//Pasting into larger existing partition, therefore block copy followed by file system
+			//  grow operations (if supported) will be performed making the file system fill the
+			//  partition.
+			partition_new .set_sector_usage(
+					new_size,
+					new_size - copied_partition .sectors_used ) ;
+		}
 		partition_new .messages .clear() ;
  
 		Operation * operation = new OperationCopy( devices[ current_device ],
@@ -1652,17 +1704,23 @@ void Win_GParted::activate_paste()
 
 		Add_Operation( operation ) ;
 
-		//Warn that paste operation will overwrite data in existing partition
-		Gtk::MessageDialog dialog( *this
-		                         , _( "You have pasted into an existing partition." )
-		                         , false
-		                         , Gtk::MESSAGE_WARNING
-		                         , Gtk::BUTTONS_OK
-		                         , true
-		                         ) ;
-		/*TO TRANSLATORS: looks like   The data in /dev/sda3 will be lost if you apply this operation. */
-		dialog .set_secondary_text( String::ucompose( _( "The data in %1 will be lost if you apply this operation."), partition_new .get_path() ) ) ;
-		dialog .run() ;
+		if ( ! shown_dialog )
+		{
+			//Only warn that this paste operation will overwrite data in the existing
+			//  partition if not already shown the remove non-empty LVM2 PV dialog.
+			Gtk::MessageDialog dialog( *this
+			                         , _( "You have pasted into an existing partition" )
+			                         , false
+			                         , Gtk::MESSAGE_WARNING
+			                         , Gtk::BUTTONS_OK
+			                         , true
+			                         ) ;
+			/*TO TRANSLATORS: looks like   The data in /dev/sda3 will be lost if you apply this operation. */
+			dialog .set_secondary_text(
+					String::ucompose( _( "The data in %1 will be lost if you apply this operation." ),
+					partition_new .get_path() ) ) ;
+			dialog .run() ;
+		}
 	}
 }
 
@@ -1703,6 +1761,13 @@ void Win_GParted::activate_new()
 
 void Win_GParted::activate_delete()
 { 
+	//VGNAME from mount mount
+	if ( selected_partition .filesystem == FS_LVM2_PV && ! selected_partition .get_mountpoint() .empty() )
+	{
+		if ( ! remove_non_empty_lvm2_pv_dialog( OPERATION_DELETE ) )
+			return ;
+	}
+
 	/* since logicals are *always* numbered from 5 to <last logical> there can be a shift
 	 * in numbers after deletion.
 	 * e.g. consider /dev/hda5 /dev/hda6 /dev/hda7. Now after removal of /dev/hda6,
@@ -1808,9 +1873,16 @@ void Win_GParted::activate_info()
 
 void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 {
+	//VGNAME from mount mount
+	if ( selected_partition .filesystem == FS_LVM2_PV && ! selected_partition .get_mountpoint() .empty() )
+	{
+		if ( ! remove_non_empty_lvm2_pv_dialog( OPERATION_FORMAT ) )
+			return ;
+	}
+
 	//check for some limits...
 	fs = gparted_core .get_fs( new_fs ) ;
-	
+
 	if ( ( selected_partition .get_byte_length() < fs .MIN ) ||
 	     ( fs .MAX && selected_partition .get_byte_length() > fs .MAX ) )
 	{
@@ -1819,7 +1891,7 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 							/* TO TRANSLATORS: looks like
 							* Cannot format this file system to fat16.
 							*/
-							_( "Cannot format this file system to %1." ),
+							_( "Cannot format this file system to %1" ),
 							   Utils::get_filesystem_string( new_fs ) ) ,
 					   false,
 					   Gtk::MESSAGE_ERROR,
@@ -1859,8 +1931,8 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 			devices[ current_device ] .sector_size,
 			selected_partition .inside_extended,
 			false ) ;
-	part_temp .Set_Unused( selected_partition .sectors_unused );
-	part_temp .set_used( 0 );
+	//Leave sector usage figures to new Partition object defaults of
+	//  -1, -1, 0 (_used, _unused, _unallocated) representing unknown.
 	 
 	part_temp .status = GParted::STAT_FORMATTED ;
 	
@@ -1971,6 +2043,23 @@ void Win_GParted::thread_toggle_swap( bool * succes, Glib::ustring * error )
 	pulse = false ;
 }
 
+void Win_GParted::thread_toggle_lvm2_pv( bool * success, Glib::ustring * error )
+{
+	Glib::ustring dummy ;
+
+	if ( selected_partition .busy )
+		//VGNAME from mount point
+		*success = ! Utils::execute_command( "lvm vgchange -a n " + selected_partition .get_mountpoint(),
+		                                     dummy,
+		                                     *error ) ;
+	else
+		*success = ! Utils::execute_command( "lvm vgchange -a y " + selected_partition .get_mountpoint(),
+		                                     dummy,
+		                                     *error ) ;
+
+	pulse = false ;
+}
+
 // Runs gpart in a thread
 void Win_GParted::thread_guess_partition_table()
 {
@@ -1979,21 +2068,22 @@ void Win_GParted::thread_guess_partition_table()
 	pulse=false;
 }
 
-void Win_GParted::toggle_swap_mount_state()
+void Win_GParted::toggle_busy_state()
 {
 	int operation_count = partition_in_operation_queue_count( selected_partition ) ;
 	if ( operation_count > 0 )
 	{
-		//Note that this situation will only occur when trying to swapon a partition.
-		//  This is because GParted does not permit queueing operations on partitions
-		//  that are currently active (i.e., swap enabled, or mounted).  Hence this
-		//  situation will not occur for the swapoff or unmount actions that this
-		//  method handles.
+		//Note that this situation will only occur when trying to swapon a partition
+		//  or activate the Volume Group of a Physical Volume.  This is because
+		//  GParted does not permit queueing operations on partitions that are
+		//  currently active (i.e., swap enabled, mounted or active VG).  Hence
+		//  this situation will not occur for the swapoff, unmount or deactivate VG
+		//  actions that this method handles.
 
 		/*TO TRANSLATORS: Singular case looks like   1 operation is currently pending for partition /dev/sdd8. */
 		Glib::ustring tmp_msg =
-		    String::ucompose( ngettext( "%1 operation is currently pending for partition %2."
-		                              , "%1 operations are currently pending for partition %2."
+		    String::ucompose( ngettext( "%1 operation is currently pending for partition %2"
+		                              , "%1 operations are currently pending for partition %2"
 		                              , operation_count
 		                              )
 		                    , operation_count
@@ -2006,9 +2096,18 @@ void Win_GParted::toggle_swap_mount_state()
 		                         , Gtk::BUTTONS_OK
 		                         , true
 		                         ) ;
-		tmp_msg  = _( "The swapon action cannot be performed if an operation is pending for the partition." ) ;
-		tmp_msg += "\n" ;
-		tmp_msg += _( "Use the Edit menu to undo, clear, or apply operations before using swapon with this partition." ) ;
+		if ( selected_partition .filesystem == GParted::FS_LINUX_SWAP )
+		{
+			tmp_msg = _( "The swapon action cannot be performed if an operation is pending for the partition." ) ;
+			tmp_msg += "\n" ;
+			tmp_msg += _( "Use the Edit menu to undo, clear, or apply operations before using swapon with this partition." ) ;
+		}
+		else if ( selected_partition .filesystem == GParted::FS_LVM2_PV )
+		{
+			tmp_msg = _( "The activate Volume Group action cannot be performed if an operation is pending for the partition." ) ;
+			tmp_msg += "\n" ;
+			tmp_msg += _( "Use the Edit menu to undo, clear, or apply operations before using activate Volume Group with this partition." ) ;
+		}
 		dialog .set_secondary_text( tmp_msg ) ;
 		dialog .run() ;
 		return ;
@@ -2044,6 +2143,34 @@ void Win_GParted::toggle_swap_mount_state()
 			dialog.run() ;
 		}
 	}
+	else if ( selected_partition .filesystem == GParted::FS_LVM2_PV )
+	{
+		thread = Glib::Thread::create( sigc::bind<bool *, Glib::ustring *>(
+			sigc::mem_fun( *this, &Win_GParted::thread_toggle_lvm2_pv ), &succes, &error ), true ) ;
+
+		show_pulsebar(
+			String::ucompose(
+				selected_partition .busy ? _("Deactivating Volume Group %1")
+				                         : _("Activating Volume Group %1"),
+				//VGNAME from mount point
+				selected_partition .get_mountpoint() ) ) ;
+
+		if ( ! succes )
+		{
+			Gtk::MessageDialog dialog(
+				*this,
+				selected_partition .busy ? _("Could not deactivate Volume Group")
+				                         : _("Could not activate Volume Group"),
+				false,
+				Gtk::MESSAGE_ERROR,
+				Gtk::BUTTONS_OK,
+				true ) ;
+
+			dialog .set_secondary_text( error ) ;
+
+			dialog.run() ;
+		}
+	}
 	else if ( selected_partition .busy )
 	{
 		thread = Glib::Thread::create( sigc::bind<bool *, Glib::ustring *>( 
@@ -2076,8 +2203,8 @@ void Win_GParted::activate_mount_partition( unsigned int index )
 	{
 		/*TO TRANSLATORS: Plural case looks like   4 operations are currently pending for partition /dev/sdd8. */
 		Glib::ustring tmp_msg =
-		    String::ucompose( ngettext( "%1 operation is currently pending for partition %2."
-		                              , "%1 operations are currently pending for partition %2."
+		    String::ucompose( ngettext( "%1 operation is currently pending for partition %2"
+		                              , "%1 operations are currently pending for partition %2"
 		                              , operation_count
 		                              )
 		                    , operation_count
@@ -2142,10 +2269,10 @@ void Win_GParted::activate_disklabel()
 	if ( active_count > 0 )
 	{
 		Glib::ustring tmp_msg =
-		    String::ucompose( /*TO TRANSLATORS: Singular case looks like  1 partition is currently active on device /dev/sda. */
-		                      ngettext( "%1 partition is currently active on device %2."
-		                      /*TO TRANSLATORS: Plural case looks like    3 partitions are currently active on device /dev/sda. */
-		                              , "%1 partitions are currently active on device %2."
+		    String::ucompose( /*TO TRANSLATORS: Singular case looks like  1 partition is currently active on device /dev/sda */
+		                      ngettext( "%1 partition is currently active on device %2"
+		                      /*TO TRANSLATORS: Plural case looks like    3 partitions are currently active on device /dev/sda */
+		                              , "%1 partitions are currently active on device %2"
 		                              , active_count
 		                              )
 		                    , active_count
@@ -2174,8 +2301,8 @@ void Win_GParted::activate_disklabel()
 	if ( operations .size() )
 	{
 		Glib::ustring tmp_msg =
-		    String::ucompose( ngettext( "%1 operation is currently pending."
-		                              , "%1 operations are currently pending."
+		    String::ucompose( ngettext( "%1 operation is currently pending"
+		                              , "%1 operations are currently pending"
 		                              , operations .size()
 		                              )
 		                    , operations .size()
@@ -2204,7 +2331,7 @@ void Win_GParted::activate_disklabel()
 		if ( ! gparted_core .set_disklabel( devices[ current_device ] .get_path(), dialog .Get_Disklabel() ) )
 		{
 			Gtk::MessageDialog dialog( *this,
-						   _("Error while creating partition table."),
+						   _("Error while creating partition table"),
 						   true,
 						   Gtk::MESSAGE_ERROR,
 						   Gtk::BUTTONS_OK,
@@ -2472,8 +2599,6 @@ int  Win_GParted::active_partitions_on_device_count( const Device & device )
 	//Count the active partitions on the device
 	for ( unsigned int k=0; k < device .partitions .size(); k++ )
 	{
-		//FIXME:  Should also count other types of active partitions, such as LVM2 when we know how.
-
 		//Count the active primary partitions
 		if (   device .partitions[ k ] .busy
 		    && device .partitions[ k ] .type != TYPE_EXTENDED
@@ -2551,4 +2676,120 @@ void Win_GParted::activate_apply()
 	}
 }
 
+bool Win_GParted::remove_non_empty_lvm2_pv_dialog( const OperationType optype )
+{
+	Glib::ustring tmp_msg ;
+	switch ( optype )
+	{
+		case OPERATION_DELETE:
+			tmp_msg = String::ucompose( _( "You are deleting non-empty LVM2 Physical Volume %1" ),
+			                            selected_partition .get_path() ) ;
+			break ;
+		case OPERATION_FORMAT:
+			tmp_msg = String::ucompose( _( "You are formatting over non-empty LVM2 Physical Volume %1" ),
+			                            selected_partition .get_path() ) ;
+			break ;
+		case OPERATION_COPY:
+			tmp_msg = String::ucompose( _( "You are pasting over non-empty LVM2 Physical Volume %1" ),
+			                            selected_partition .get_path() ) ;
+			break ;
+		default:
+			break ;
+	}
+	Gtk::MessageDialog dialog( *this, tmp_msg,
+	                           false, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE, true ) ;
+
+	tmp_msg =  _( "Deleting or overwriting the Physical Volume is irrecoverable and will destroy or damage the "
+	              " Volume Group." ) ;
+	tmp_msg += "\n\n" ;
+	tmp_msg += _( "To avoid destroying or damaging the Volume Group, you are advised to cancel and use external "
+	              "LVM commands to free the Physical Volume before attempting this operation." ) ;
+	tmp_msg += "\n\n" ;
+	tmp_msg += _( "Do you want to continue to forcibly delete the Physical Volume?" ) ;
+
+	LVM2_PV_Info lvm2_pv_info ;
+	Glib::ustring vgname = lvm2_pv_info .get_vg_name( selected_partition .get_path() ) ;
+	std::vector<Glib::ustring> members ;
+	if ( ! vgname .empty() )
+		members = lvm2_pv_info .get_vg_members( vgname ) ;
+
+	//Single copy of each string for translation purposes
+	const Glib::ustring vgname_label  = _( "Volume Group:" ) ;
+	const Glib::ustring members_label = _( "Members:" ) ;
+
+#ifndef HAVE_GET_MESSAGE_AREA
+	//Basic method of displaying VG members by appending it to the secondary text in the dialog.
+	tmp_msg += "\n____________________\n\n" ;
+	tmp_msg += "<b>" ;
+	tmp_msg +=       vgname_label ;
+	tmp_msg +=                    "</b>    " ;
+	tmp_msg +=                               vgname ;
+	tmp_msg += "\n" ;
+	tmp_msg += "<b>" ;
+	tmp_msg +=       members_label ;
+	tmp_msg +=                     "</b>" ;
+	if ( ! members .empty() )
+	{
+		tmp_msg += "    " ;
+		tmp_msg +=        members [0] ;
+		for ( unsigned int i = 1 ; i < members .size() ; i ++ )
+		{
+			tmp_msg += "    " ;
+			tmp_msg +=        members [i] ;
+		}
+	}
+#endif /* ! HAVE_GET_MESSAGE_AREA */
+
+	dialog .set_secondary_text( tmp_msg, true ) ;
+
+#ifdef HAVE_GET_MESSAGE_AREA
+	//Nicely formatted method of displaying VG members by using a table below the secondary text
+	//  in the dialog.  Uses Gtk::MessageDialog::get_message_area() which was new in gtkmm-2.22
+	//  released September 2010.
+	Gtk::Box * msg_area = dialog .get_message_area() ;
+
+	Gtk::HSeparator * hsep( manage( new Gtk::HSeparator() ) ) ;
+	msg_area ->pack_start( * hsep ) ;
+
+	Gtk::Table * table( manage( new Gtk::Table() ) ) ;
+        table ->set_border_width( 0 ) ;
+        table ->set_col_spacings( 10 ) ;
+        msg_area ->pack_start( * table ) ;
+
+	int top = 0, bottom = 1 ;
+
+	//Volume Group
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( vgname_label ) + "</b>" ),
+	                0, 1, top, bottom, Gtk::FILL ) ;
+	table ->attach( * Utils::mk_label( vgname, true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+	                1, 2, top++, bottom++, Gtk::FILL ) ;
+
+	//Members
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( members_label ) + "</b>"),
+			0, 1, top, bottom, Gtk::FILL ) ;
+
+	if ( members .empty() )
+		table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL ) ;
+	else
+	{
+		table ->attach( * Utils::mk_label( members [0], true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+				1, 2, top++, bottom++, Gtk::FILL ) ;
+		for ( unsigned int i = 1 ; i < members .size() ; i ++ )
+		{
+			table ->attach( * Utils::mk_label( "" ), 0, 1, top, bottom, Gtk::FILL ) ;
+			table ->attach( * Utils::mk_label( members [i], true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ),
+					1, 2, top++, bottom++, Gtk::FILL ) ;
+		}
+
+	}
+#endif /* HAVE_GET_MESSAGE_AREA */
+
+	dialog .add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
+	dialog .add_button( Gtk::Stock::DELETE, Gtk::RESPONSE_OK );
+	dialog .show_all() ;
+	if ( dialog .run() == Gtk::RESPONSE_OK )
+		return true ;
+	return false ;
+}
+
 } // GParted
