@@ -29,6 +29,7 @@ FS exfat::get_filesystem_support()
 	
 	fs .copy = FS::GPARTED ;
 	fs .move = FS::GPARTED ;
+	fs .online_read = FS::GPARTED ;
 	
 	return fs ;
 }
@@ -88,5 +89,10 @@ bool exfat::check_repair( const Partition & partition, OperationDetail & operati
 	return true ;
 }
 
+bool exfat::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
 
