@@ -30,7 +30,7 @@ namespace GParted
 {
 
 const Glib::ustring fat16::Change_UUID_Warning [] =
-	{ _( "Changing the UUID might invalidate the Windows Product Activation (WPA) key."
+	{ _( "Changing the UUID might invalidate the Windows Product Activation (WPA) key"
 	   )
 	, _( "On FAT and NTFS file systems, the"
 	     " Volume Serial Number is used as the UUID."
@@ -94,7 +94,8 @@ FS fat16::get_filesystem_support()
 #endif
 
 	fs .copy = GParted::FS::GPARTED ;
-	
+	fs .online_read = FS::GPARTED ;
+
 	fs .MIN = 16 * MEBIBYTE ;
 	fs .MAX = (4096 - 1) * MEBIBYTE ;  //Maximum seems to be just less than 4096 MiB
 	
@@ -106,6 +107,19 @@ void fat16::set_used_sectors( Partition & partition )
 	exit_status = Utils::execute_command( "dosfsck -n -v " + partition .get_path(), output, error, true ) ;
 	if ( exit_status == 0 || exit_status == 1 || exit_status == 256 )
 	{
+		//total file system size in logical sectors
+		index = output .rfind( "\n", output .find( "sectors total" ) ) +1 ;
+		if ( index >= output .length() || sscanf( output .substr( index ) .c_str(), "%Ld", &T ) != 1 )
+			T = -1 ;
+
+		//bytes per logical sector
+		index = output .rfind( "\n", output .find( "bytes per logical sector" ) ) +1 ;
+		if ( index >= output .length() || sscanf( output .substr( index ) .c_str(), "%Ld", &S ) != 1 )
+			S = -1 ;
+
+		if ( T > -1 && S > -1 )
+			T = Utils::round( T * ( S / double(partition .sector_size) ) ) ;
+
 		//free clusters
 		index = output .find( ",", output .find( partition .get_path() ) + partition .get_path() .length() ) +1 ;
 		if ( index < output .length() && sscanf( output .substr( index ) .c_str(), "%Ld/%Ld", &S, &N ) == 2 ) 
@@ -119,7 +133,10 @@ void fat16::set_used_sectors( Partition & partition )
 			S = -1 ;
 	
 		if ( N > -1 && S > -1 )
-			partition .Set_Unused( Utils::round( N * ( S / double(partition .sector_size) ) ) ) ;
+			N = Utils::round( N * ( S / double(partition .sector_size) ) ) ;
+
+		if ( T > -1 && N > -1 )
+			partition .set_sector_usage( T, N ) ;
 	}
 	else
 	{
@@ -280,6 +297,11 @@ bool fat16::check_repair( const Partition & partition, OperationDetail & operati
 	return ( exit_status == 0 || exit_status == 1 || exit_status == 256 ) ;
 }
 
+bool fat16::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
 
 
