@@ -44,7 +44,8 @@ FS hfs::get_filesystem_support()
 
 	fs .copy = GParted::FS::GPARTED ;
 	fs .move = GParted::FS::GPARTED ;
-	
+	fs .online_read = FS::GPARTED ;
+
 	fs .MAX = 2048 * MEBIBYTE ;
 	
 	return fs ;
@@ -123,4 +124,9 @@ bool hfs::check_repair( const Partition & partition, OperationDetail & operation
 	return ! execute_command( "hfsck -v " + partition .get_path(), operationdetail ) ;
 }
 
+bool hfs::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
