@@ -44,7 +44,8 @@ FS hfsplus::get_filesystem_support()
 
 	fs .copy = GParted::FS::GPARTED ;
 	fs .move = GParted::FS::GPARTED ;
-	
+	fs .online_read = FS::GPARTED ;
+
 	return fs ;
 }
 
@@ -120,4 +121,9 @@ bool hfsplus::check_repair( const Partition & partition, OperationDetail & opera
 	return ! execute_command( "fsck.hfsplus -f -y " + partition .get_path(), operationdetail ) ;
 }
 
+bool hfsplus::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
