@@ -19,8 +19,6 @@
  
 #include "../include/jfs.h"
 
-#include <cerrno>
-
 namespace GParted
 {
 
@@ -31,12 +29,12 @@ FS jfs::get_filesystem_support()
 		
 	if ( ! Glib::find_program_in_path( "jfs_debugfs" ) .empty() ) {
 		fs .read = GParted::FS::EXTERNAL ;
-		fs .read_uuid = GParted::FS::EXTERNAL ;
 	}
 	
 	if ( ! Glib::find_program_in_path( "jfs_tune" ) .empty() ) {
 		fs .read_label = FS::EXTERNAL ;
 		fs .write_label = FS::EXTERNAL ;
+		fs .read_uuid = FS::EXTERNAL ;
 		fs .write_uuid = FS::EXTERNAL ;
 	}
 
@@ -60,7 +58,9 @@ FS jfs::get_filesystem_support()
 		fs .move = GParted::FS::GPARTED ;
 		fs .copy = GParted::FS::GPARTED ;
 	}
-	
+
+	fs .online_read = FS::GPARTED ;
+
 	fs .MIN = 16 * MEBIBYTE ;
 	
 	return fs ;
@@ -75,15 +75,25 @@ void jfs::set_used_sectors( Partition & partition )
 		if ( index >= output .length() || 
 		     sscanf( output .substr( index ) .c_str(), "Block Size: %Ld", &S ) != 1 ) 
 			S = -1 ;
-		
+
+		//total blocks
+		index = output .find( "dn_mapsize:" ) ;
+		if ( index >= output .length() ||
+		     sscanf( output .substr( index ) .c_str(), "dn_mapsize: %Lx", &T ) != 1 )
+			T = -1 ;
+
 		//free blocks
 		index = output .find( "dn_nfree:" ) ;
 		if ( index >= output .length() || 
 		     sscanf( output .substr( index ) .c_str(), "dn_nfree: %Lx", &N ) != 1 ) 
 			N = -1 ;
 
-		if ( S > -1 && N > -1 )
-			partition .Set_Unused( Utils::round( N * ( S / double(partition .sector_size) ) ) ) ;
+		if ( T > -1 && N > -1 && S > -1 )
+		{
+			T = Utils::round( T * ( S / double(partition .sector_size) ) ) ;
+			N = Utils::round( N * ( S / double(partition .sector_size) ) ) ;
+			partition .set_sector_usage( T, N ) ;
+		}
 	}
 	else
 	{
@@ -118,11 +128,9 @@ bool jfs::write_label( const Partition & partition, OperationDetail & operationd
 
 void jfs::read_uuid( Partition & partition )
 {
-	if ( ! Utils::execute_command( "echo su | jfs_debugfs " + partition .get_path(), output, error, true ) )
+	if ( ! Utils::execute_command( "jfs_tune -l " + partition .get_path(), output, error, true ) )
 	{
-		partition .uuid = Utils::regexp_label( output, "s_uuid:[[:blank:]]*([^[:space:]]+)" ) ;
-		if ( partition .uuid == "00000000-0000-0000-0000-000000000000" )
-			partition .uuid .clear() ;
+		partition .uuid = Utils::regexp_label( output, "^File system UUID:[[:blank:]]*(" RFC4122_NONE_NIL_UUID_REGEXP ")" ) ;
 	}
 	else
 	{
@@ -190,6 +198,11 @@ bool jfs::check_repair( const Partition & partition, OperationDetail & operation
 	return ( exit_status == 0 || exit_status == 1 ) ;
 }
 
+bool jfs::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
 
 
