@@ -55,6 +55,7 @@ FS nilfs2::get_filesystem_support()
 
 	fs .copy = GParted::FS::GPARTED ;
 	fs .move = GParted::FS::GPARTED ;
+	fs .online_read = FS::GPARTED ;
 
 	//Minimum FS size is 128M+4K using mkfs.nilfs2 defaults
 	fs .MIN = 128 * MEBIBYTE + 4 * KIBIBYTE ;
@@ -66,7 +67,15 @@ void nilfs2::set_used_sectors( Partition & partition )
 {
 	if ( ! Utils::execute_command( "nilfs-tune -l " + partition .get_path(), output, error, true ) )
 	{
-		Glib::ustring::size_type index = output .find( "Free blocks count:" ) ;
+		//File system size in bytes
+		Glib::ustring::size_type index = output .find( "Device size:" ) ;
+		if (   index == Glib::ustring::npos
+		    || sscanf( output.substr( index ) .c_str(), "Device size: %Ld", &T ) != 1
+		   )
+			T = -1 ;
+
+		//Free space in blocks
+		index = output .find( "Free blocks count:" ) ;
 		if (   index == Glib::ustring::npos
 		    || sscanf( output.substr( index ) .c_str(), "Free blocks count: %Ld", &N ) != 1
 		   )
@@ -78,8 +87,12 @@ void nilfs2::set_used_sectors( Partition & partition )
 		   )
 			S = -1 ;
 
-		if ( N > -1 && S > -1 )
-			partition .Set_Unused( Utils::round( N * ( S / double( partition .sector_size) ) ) ) ;
+		if ( T > -1 && N > -1 && S > -1 )
+		{
+			T = Utils::round( T / double(partition .sector_size) ) ;
+			N = Utils::round( N * ( S / double(partition .sector_size) ) ) ;
+			partition .set_sector_usage( T, N ) ;
+		}
 	}
 	else
 	{
@@ -118,9 +131,7 @@ void nilfs2::read_uuid( Partition & partition )
 {
 	if ( ! Utils::execute_command( "nilfs-tune -l " + partition .get_path(), output, error, true ) )
 	{
-		partition .uuid = Utils::regexp_label( output, "^Filesystem UUID:[[:blank:]]*([^[:space:]]*)" ) ;
-		if (partition .uuid == "00000000-0000-0000-0000-000000000000")
-			partition .uuid .clear() ;
+		partition .uuid = Utils::regexp_label( output, "^Filesystem UUID:[[:blank:]]*(" RFC4122_NONE_NIL_UUID_REGEXP ")" ) ;
 	}
 	else
 	{
@@ -193,4 +204,9 @@ bool nilfs2::check_repair( const Partition & partition, OperationDetail & operat
 	return true ;
 }
 
+bool nilfs2::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
