@@ -23,7 +23,7 @@ namespace GParted
 {
 
 const Glib::ustring ntfs::Change_UUID_Warning [] =
-	{ _( "Changing the UUID might invalidate the Windows Product Activation (WPA) key."
+	{ _( "Changing the UUID might invalidate the Windows Product Activation (WPA) key"
 	   )
 	, _( "On FAT and NTFS file systems, the"
 	     " Volume Serial Number is used as the UUID."
@@ -102,7 +102,9 @@ FS ntfs::get_filesystem_support()
 
 	if ( fs .check )
 		fs .move = GParted::FS::GPARTED ;
-	
+
+	fs .online_read = FS::GPARTED ;
+
 	return fs ;
 }
 
@@ -111,13 +113,22 @@ void ntfs::set_used_sectors( Partition & partition )
 	if ( ! Utils::execute_command( 
 		"ntfsresize --info --force --no-progress-bar " + partition .get_path(), output, error, true ) )
 	{
+		index = output .find( "Current volume size:" ) ;
+		if ( index >= output .length() ||
+		     sscanf( output .substr( index ) .c_str(), "Current volume size: %Ld", &T ) != 1 )
+			T = -1 ;
+
 		index = output .find( "resize at" ) ;
 		if ( index >= output .length() ||
 		     sscanf( output .substr( index ) .c_str(), "resize at %Ld", &N ) != 1 )
 			N = -1 ;
 
-		if ( N > -1 )
-			partition .set_used( Utils::round( N / double(partition .sector_size) ) ) ; 
+		if ( T > -1 && N > -1 )
+		{
+			T = Utils::round( T / double(partition .sector_size) ) ;
+			N = Utils::round( N / double(partition .sector_size) ) ;
+			partition .set_sector_usage( T, T - N );
+		}
 	}
 	else
 	{
@@ -229,6 +240,11 @@ bool ntfs::check_repair( const Partition & partition, OperationDetail & operatio
 	return ! execute_command( "ntfsresize -P -i -f -v " + partition .get_path(), operationdetail ) ; 
 }
 
+bool ntfs::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
 
 
