@@ -30,12 +30,10 @@ FS reiser4::get_filesystem_support()
 	if ( ! Glib::find_program_in_path( "debugfs.reiser4" ) .empty() )
 	{
 		fs .read = GParted::FS::EXTERNAL ;
+		fs .read_label = FS::EXTERNAL ;
 		fs .read_uuid = GParted::FS::EXTERNAL ;
 	}
-	
-	if ( ! Glib::find_program_in_path( "vol_id" ) .empty() )
-		fs .read_label = FS::EXTERNAL ;
-	
+
 	if ( ! Glib::find_program_in_path( "mkfs.reiser4" ) .empty() )
 		fs .create = GParted::FS::EXTERNAL ;
 	
@@ -47,7 +45,9 @@ FS reiser4::get_filesystem_support()
 		fs .copy = GParted::FS::GPARTED ;
 		fs .move = GParted::FS::GPARTED ;
 	}
-	
+
+	fs .online_read = FS::GPARTED ;
+
 	/*
 	 * IT SEEMS RESIZE AND COPY AREN'T IMPLEMENTED YET IN THE TOOLS...
 	 * SEE http://marc.theaimsgroup.com/?t=109883161600003&r=1&w=2 for more information.. 
@@ -60,18 +60,27 @@ void reiser4::set_used_sectors( Partition & partition )
 {
 	if ( ! Utils::execute_command( "debugfs.reiser4 " + partition .get_path(), output, error, true ) )
 	{
-		index = output .find( "free blocks" ) ;
+		index = output .find( "\nblocks:" ) ;
 		if ( index >= output .length() ||
-		     sscanf( output.substr( index ) .c_str(), "free blocks: %Ld", &N ) != 1 )   
+		     sscanf( output.substr( index ) .c_str(), "\nblocks: %Ld", &T ) != 1 )
+			T = -1 ;
+
+		index = output .find( "\nfree blocks:" ) ;
+		if ( index >= output .length() ||
+		     sscanf( output.substr( index ) .c_str(), "\nfree blocks: %Ld", &N ) != 1 )
 			N = -1 ;
-	
-		index = output .find( "blksize" ) ;
+
+		index = output .find( "\nblksize:" ) ;
 		if ( index >= output.length() ||
-		     sscanf( output.substr( index ) .c_str(), "blksize: %Ld", &S ) != 1 )  
+		     sscanf( output.substr( index ) .c_str(), "\nblksize: %Ld", &S ) != 1 )
 			S = -1 ;
 
-		if ( N > -1 && S > -1 )
-			partition .Set_Unused( Utils::round( N * ( S / double(partition .sector_size) ) ) ) ;
+		if ( T > -1 && N > -1 && S > -1 )
+		{
+			T = Utils::round( T * ( S / double(partition .sector_size) ) ) ;
+			N = Utils::round( N * ( S / double(partition .sector_size) ) ) ;
+			partition .set_sector_usage( T, N ) ;
+		}
 	}
 	else
 	{
@@ -85,9 +94,9 @@ void reiser4::set_used_sectors( Partition & partition )
 
 void reiser4::read_label( Partition & partition )
 {
-	if ( ! Utils::execute_command( "vol_id " + partition .get_path(), output, error, true ) )
+	if ( ! Utils::execute_command( "debugfs.reiser4 " + partition .get_path(), output, error, true ) )
 	{
-		partition .label = Utils::regexp_label( output, "ID_FS_LABEL=([^\n]*)" ) ;
+		partition .label = Utils::regexp_label( output, "^label:[[:blank:]]*(.*)$" ) ;
 	}
 	else
 	{
@@ -108,7 +117,7 @@ void reiser4::read_uuid( Partition & partition )
 {
 	if ( ! Utils::execute_command( "debugfs.reiser4 " + partition .get_path(), output, error, true ) )
 	{
-		partition .uuid = Utils::regexp_label( output, "uuid:[[:blank:]]*([^[:space:]]*)" ) ;
+		partition .uuid = Utils::regexp_label( output, "uuid:[[:blank:]]*(" RFC4122_NONE_NIL_UUID_REGEXP ")" ) ;
 	}
 	else
 	{
@@ -155,6 +164,11 @@ bool reiser4::check_repair( const Partition & partition, OperationDetail & opera
 	return ! execute_command( "fsck.reiser4 --yes --fix --quiet " + partition .get_path(), operationdetail ) ;
 }
 
+bool reiser4::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
 
 
