@@ -61,6 +61,8 @@ FS reiserfs::get_filesystem_support()
 		fs .move = GParted::FS::GPARTED ;
 	}
 
+	fs .online_read = FS::GPARTED ;
+
 	//Actual minimum is at least 18 blocks larger than 32 MiB for the journal offset
 	fs .MIN = 34 * MEBIBYTE ;
 	
@@ -71,7 +73,12 @@ void reiserfs::set_used_sectors( Partition & partition )
 {
 	if ( ! Utils::execute_command( "debugreiserfs " + partition .get_path(), output, error, true ) )
 	{
-		index = output .find( "Blocksize" ) ;
+		index = output .find( "Count of blocks on the device:" ) ;
+		if ( index >= output .length() ||
+		     sscanf( output .substr( index ) .c_str(), "Count of blocks on the device: %Ld", &T ) != 1 )
+			T = -1 ;
+
+		index = output .find( "Blocksize:" ) ;
 		if ( index >= output .length() || 
 		     sscanf( output .substr( index ) .c_str(), "Blocksize: %Ld", &S ) != 1 )
 			S = -1 ;
@@ -81,8 +88,12 @@ void reiserfs::set_used_sectors( Partition & partition )
 		     sscanf( output .substr( index ) .c_str(), "%Ld", &N ) != 1 )
 			N = -1 ;
 
-		if ( N > -1 && S > -1 )
-			partition .Set_Unused( Utils::round( N * ( S / double(partition .sector_size) ) ) ) ;
+		if ( T > -1 && N > -1 && S > -1 )
+		{
+			T = Utils::round( T * ( S / double(partition .sector_size) ) ) ;
+			N = Utils::round( N * ( S / double(partition .sector_size) ) ) ;
+			partition .set_sector_usage( T, N ) ;
+		}
 	}
 	else
 	{
@@ -96,7 +107,6 @@ void reiserfs::set_used_sectors( Partition & partition )
 
 void reiserfs::read_label( Partition & partition )
 {
-	//FIXME: i think running debugreiserfs takes a long time on filled file systems, test for this...
 	if ( ! Utils::execute_command( "debugreiserfs " + partition .get_path(), output, error, true ) )
 	{
 		partition .label = Utils::regexp_label( output, "^label:[\t ]*(.*)$" ) ;
@@ -118,9 +128,9 @@ bool reiserfs::write_label( const Partition & partition, OperationDetail & opera
 
 void reiserfs::read_uuid( Partition & partition )
 {
-	if ( ! Utils::execute_command( "reiserfstune " + partition .get_path(), output, error, true ) )
+	if ( ! Utils::execute_command( "debugreiserfs " + partition .get_path(), output, error, true ) )
 	{
-		partition .uuid = Utils::regexp_label( output, "^UUID:[[:blank:]]*([^[:space:]]*)" ) ;
+		partition .uuid = Utils::regexp_label( output, "^UUID:[[:blank:]]*(" RFC4122_NONE_NIL_UUID_REGEXP ")" ) ;
 	}
 	else
 	{
@@ -180,4 +190,9 @@ bool reiserfs::check_repair( const Partition & partition, OperationDetail & oper
 	return ( exit_status == 0 || exit_status == 1 || exit_status == 256 ) ;
 }
 
+bool reiserfs::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
