@@ -30,7 +30,8 @@ FS ufs::get_filesystem_support()
 	
 	fs .copy = GParted::FS::GPARTED ;
 	fs .move = GParted::FS::GPARTED ;
-	
+	fs .online_read = FS::GPARTED ;
+
 	return fs ;
 }
 
@@ -86,6 +87,11 @@ bool ufs::check_repair( const Partition & partition, OperationDetail & operation
 	return true ;
 }
 
+bool ufs::remove( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 } //GParted
 
 
